import nodemailer from 'nodemailer';
import type { ContactRequest } from '@shared/schema';

const transporter = nodemailer.createTransport({
  host: 'lubsat.co.za',
  port: 465,
  secure: true, // true for port 465
  auth: {
    user: 'juma@lubsat.co.za',
    pass: process.env.EMAIL_PASSWORD,
  },
  tls: {
    rejectUnauthorized: false // Accept self-signed certificates
  }
});

export async function sendContactEmail(contactData: ContactRequest): Promise<void> {
  const mailOptions = {
    from: 'juma@lubsat.co.za',
    to: 'info@lubsat.co.za',
    subject: `New Contact Form Submission - ${contactData.service}`,
    html: `
      <h2>New Contact Form Submission</h2>
      <p><strong>Name:</strong> ${contactData.firstName} ${contactData.lastName}</p>
      <p><strong>Email:</strong> ${contactData.email}</p>
      <p><strong>Phone:</strong> ${contactData.phone}</p>
      <p><strong>Service:</strong> ${contactData.service}</p>
      ${contactData.address ? `<p><strong>Address:</strong> ${contactData.address}</p>` : ''}
      ${contactData.urgency ? `<p><strong>Urgency:</strong> ${contactData.urgency}</p>` : ''}
      ${contactData.message ? `<p><strong>Message:</strong> ${contactData.message}</p>` : ''}
      <p><strong>Newsletter Subscription:</strong> ${contactData.newsletter ? 'Yes' : 'No'}</p>
      <p><strong>Submitted:</strong> ${contactData.createdAt ? new Date(contactData.createdAt).toLocaleString() : 'Unknown'}</p>
    `,
  };

  try {
    await transporter.sendMail(mailOptions);
    console.log('Email sent successfully to info@lubsat.co.za');
  } catch (error) {
    console.error('Failed to send email:', error);
    throw new Error('Failed to send email notification');
  }
}